#!/usr/bin/env python

# import logging

# from zimscraperlib.logging import getLogger

# logger = getLogger(__name__, level=logging.DEBUG)

# TMP_FOLDER = "tmp"

# VERSION = "0.0.1"

# #LANGS = ["fr", "en", "de", "it", "es", "pt", "tr", "jp", "nl", "ru", "zh", "ko"]
# LANGS = ["en"]
