#mainHeader,footer{display:none!important}#background{background-color:#fff!important}#background #mainBody{box-shadow:none}#background #banner-wrap-bg{display:none}#background .banner-content{background-image:none;background-color:#fff}#background .banner-blurb,#background .banner-title{color:#212426;text-shadow:none}#background #bodyTop,#background #dozukiSidebarAd,#background #guideBottom,#background .addNote,#background .buttonLink,#background .noteToggle,#background .socialMediaLinks,#background .stepTitle .anchor,#background .stepTitle .edit,#background .stepViewOptions,#background .wikiDetailsOther,#background .wikiDetailsResources{display:none}#background .step{page-break-inside:avoid}