#content *{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.page-callout{position:relative;margin-top:36px}.page-callout-inner{border-radius:6px;overflow:hidden;max-height:211px}.page-callout-inner>img:first-of-type{max-width:100%}.close-callout{position:absolute;top:10px;right:10px}.page-callout-content{width:250px;text-align:center;position:absolute;right:24px;top:28px}.page-callout-content h2,.page-callout-content p strong{color:#fff}.page-callout-content h2{font-size:26px;border:0;font-weight:700}.page-callout-content p{color:#fff;font-size:16px;margin-bottom:16px}.page-callout-content p strong{font-size:17px}.featured-categories{display:-ms-flexbox;display:-webkit-flex;display:flex;-ms-justify-content:flex-start;-webkit-justify-content:flex-start;justify-content:flex-start;-ms-flex-pack:start;-webkit-flex-wrap:wrap;flex-wrap:wrap;-ms-flex-wrap:wrap}@media only screen and (max-width:599px){.featured-categories{-ms-justify-content:center;-webkit-justify-content:center;justify-content:center;-ms-flex-pack:center}}.featured-category-item{position:relative;-ms-flex:1 auto;-webkit-flex:1 auto;flex:1 auto;width:233px;margin:8px;overflow:hidden}@media only screen and (max-width:1000px){.featured-category-item{width:20%}}@media only screen and (max-width:599px){.featured-category-item{width:44%}}.featured-category-item:hover{text-decoration:none}.featured-category-item:hover img{-webkit-transform:scale(1.1);transform:scale(1.1)}.featured-category-item:hover .shadow-overlay{background-color:rgba(0,117,206,.9)}.featured-category-item img{width:120%;height:auto;margin-top:10px;margin-left:-10%;-webkit-transition:all .2s ease-in-out;transition:all .2s ease-in-out}@media only screen and (max-width:1000px){.featured-category-item img{-webkit-transition:0;transition:0}}.shadow-overlay{position:absolute;top:0;left:0;width:100%;height:100%;background-color:rgba(54,60,64,.8);z-index:9;-webkit-transition:background-color .2s ease-in-out;transition:background-color .2s ease-in-out}.ie8 .shadow-overlay{background-color:#363c40}.ie8 .shadow-overlay:hover{background-color:#3b82f6}.featured-category-title{z-index:10;position:absolute;top:0;bottom:0;left:0;right:0;height:40px;width:100%;margin:auto;font-size:26px;font-weight:600;color:#fff;text-align:center}@media only screen and (max-width:599px){.featured-category-title{font-size:19px}}@media only screen and (max-width:599px),only screen and (min-width:1001px){.collection-guides .blurbListCell:nth-of-type(n+9){display:none}}.section-divider{width:100%;height:1px;background-color:#d4d7dd;position:relative;margin:48px 0;text-align:center;padding:0}@media only screen and (max-width:599px){.section-divider{margin:64px 0}}.section-divider p{display:inline-block;padding:0 20px;margin:0;position:relative;background-color:#fff;top:-10px}.section-divider.primary-divider p{font-size:18px;font-weight:600}.section-divider.secondary-divider p{font-size:13px;font-weight:400}.filter-container{margin-bottom:24px}.filter-container h2{font-size:24px;font-weight:600;border-bottom:0}.sub-categories{display:-ms-flexbox;display:-webkit-flex;display:flex;-webkit-flex-wrap:wrap;flex-wrap:wrap;-ms-flex-wrap:wrap;-ms-justify-content:flex-start;-webkit-justify-content:flex-start;justify-content:flex-start;-ms-flex-pack:start}.sub-category{position:relative;width:23%;width:calc(25% - 14px);text-align:center;background-color:#f9fafb;overflow:hidden;margin:7px;padding:13px 0}@media only screen and (max-width:599px){.sub-category{width:100%}}@media only screen and (min-width:600px) and (max-width:1000px){.sub-category{width:31%}}.sub-category:hover{background-color:#b1cdfb;text-decoration:none}.sub-category:hover .sub-category-title{color:#3b82f6}.sub-category:hover .overflow-slide-in{left:0}.sub-category-title{font-size:16px;color:#212426}.overflow-slide-in{position:absolute;top:0;left:-60px;font-weight:700;padding:13px 0;width:60px;background-color:#3b82f6;color:#fff;overflow:hidden;-webkit-transition:left .2s ease-in-out;transition:left .2s ease-in-out}.overflow-slide-in i{display:block;margin-bottom:2px;font-size:14px;color:#6aafeb}